
.. pytango-client-green-api:

=========
Green API
=========

Summary:
    * :func:`tango.get_green_mode`
    * :func:`tango.set_green_mode`
    * :func:`tango.asyncio.DeviceProxy`
    * :func:`tango.futures.DeviceProxy`
    * :func:`tango.gevent.DeviceProxy`

.. autofunction:: tango.get_green_mode

.. autofunction:: tango.set_green_mode

.. autofunction:: tango.asyncio.DeviceProxy

.. autofunction:: tango.futures.DeviceProxy

.. autofunction:: tango.gevent.DeviceProxy
